@@ -340,6 +340,8 @@ int main(int argc, char *argv[])
 		exit_fault(ENOMEM);
 
 	/* load the bpf program */
+	if (opt_file == NULL)
+		exit_usage(argv[0]);
 	file = fopen(opt_file, "r");
 	if (file == NULL)
 		exit_fault(errno);
